server_client_20150129_153254

### config1 : test_redlining

Result | Function execution time | Total execution time
--- | --- | ---
Failed | 1.97678804398 sec | 4.12337994576 sec

Error message: server latency too high while sending 10000 integers

Naarad report

### Metrics

#### server1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
latency | 4.25 | 0.29 | 0.21 | 0.27 | 0.29 | 0.36 | 0.41 | 0.64 | 0.14
qps | 826.00 | 500.50 | 175.00 | 500.50 | 663.25 | 760.90 | 793.45 | 819.49 | 325.50

#### client1-perf

Submetric | max | mean | min | p50 | p75 | p90 | p95 | p99 | std
--- | --- | --- | --- | --- | --- | --- | --- | --- | ---
qps | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 1.0 | 0.0
latency | 1233.84 | 1233.84 | 1233.84 | 1233.84 | 1233.84 | 1233.84 | 1233.84 | 1233.84 | 0.0

### SLAs

metric | submetric | sla rule | value
--- | --- | --- | ---
server1-perf | latency | p50 lt 0.3 | 0.272
server1-perf | latency | mean lt 0.33 | 0.291114885115
server1-perf | qps | mean lt 7.0 | 500.5
server2-perf | latency | p50 lt 0.3 | None
server2-perf | latency | mean lt 0.33 | None
server2-perf | qps | mean lt 7.0 | None
server3-perf | latency | p50 lt 0.3 | None
server3-perf | latency | mean lt 0.33 | None
server3-perf | qps | mean lt 7.0 | None
client1-perf | latency | p50 lt 22.0 | 1233.84
client1-perf | latency | mean lt 35.0 | 1233.84
client1-perf | qps | mean lt 2.0 | 1.0
client2-perf | latency | p50 lt 22.0 | None
client2-perf | latency | mean lt 35.0 | None
client2-perf | qps | mean lt 2.0 | None